@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 #
-# Copyright 2019-2020 Flavio Garcia
+# Copyright 2019-2023 Flávio Gonçalves Garcia
 # Copyright 2016-2017 Veeti Paananen under MIT License
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -20,6 +20,7 @@ Cryptography, hopefully mostly correct.
 """
 
 import base64
+import binascii
 import json
 import logging
 # TODO: Remove that after python 3.5 depreciation
@@ -31,8 +32,7 @@ from cryptography.x509 import NameOID
 from cryptography.hazmat.backends import default_backend
 from cryptography.hazmat.primitives.asymmetric import padding
 from cryptography.hazmat.primitives.asymmetric.rsa import (
-    generate_private_key,
-    RSAPrivateKey,
+    generate_private_key, RSAPrivateKey, RSAPrivateNumbers, RSAPublicNumbers
 )
 from cryptography.hazmat.primitives.asymmetric.ec import (
     EllipticCurvePrivateKey,
@@ -64,6 +64,32 @@ def generate_rsa_key(size=2048):
     return generate_private_key(65537, size, default_backend())
 
 
+def generate_rsa_key_from_parameters(
+        p, q, d, dmp1, dmq1, iqmp, e, n
+) -> RSAPrivateKey:
+    """
+    Note: from certbot dp is dmp1, dq is dmq1 and qi is iqmp
+    """
+    public_numbers = RSAPublicNumbers(e, n)
+    return RSAPrivateNumbers(
+        p, q, d, dmp1, dmq1, iqmp, public_numbers
+    ).private_key(default_backend())
+
+
+def data_to_hex(data: bytes) -> bytes:
+    missing_padding = 4 - len(data) % 4
+    if missing_padding:
+        data += b"=" * missing_padding
+    return b"0x" + binascii.hexlify(base64.b64decode(data, b'-_')).upper()
+
+
+def certbot_key_data_to_int(key_data: dict) -> dict:
+    key_data_int = {}
+    for key, value in key_data.items():
+        key_data_int[key] = int(data_to_hex(value.encode()), 16)
+    return key_data_int
+
+
 def generate_header(account_key):
     """
     Creates a new request header for the specified account key.
